(merge-statuses [fst & rst])Combines many statuses into one overall status that conveys the minimum/worst case of all of the statuses
Combines many statuses into one overall status that conveys the minimum/worst case of all of the statuses
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |